import pandas as pd
from scipy.interpolate import interp1d
import pathlib

root_dir = pathlib.Path(__file__).parent.parent
data_dir = root_dir / "data"


# Material definitions and interpolation
class SiMaterial:
    def __init__(self):

        # Data is from refrativeindex.info
        material_file = data_dir / "Aspnes.csv"

        # Read the material file
        n_data = pd.read_csv(material_file, nrows=46)
        k_data = pd.read_csv(material_file, skiprows=48)

        # Create interpolators for material data
        self._n_interpolator = interp1d(
            n_data["wl"] * 1e3,
            n_data["n"],
            kind="linear",
        )
        self._k_interpolator = interp1d(
            k_data["wl"] * 1e3,
            k_data["k"],
            kind="linear",
        )

    def nk(self, wavelength):
        return self._n_interpolator(wavelength) + 1j * self._k_interpolator(wavelength)
